@@ -16,6 +16,11 @@ const REVISION_CONFIG = {
             name: "N_JOBS_PER_WORKER",
             value: "100",
             type: "secret"
+        },
+        {
+            name: "FF_LOG_DROPPED_EVENTS",
+            value: "true",
+            type: "secret"
         }
     ],
     shareable: false
