@@ -12,12 +12,13 @@ from starlette.responses import Response
 from starlette.routing import BaseRoute
 
 from langgraph_api import store as api_store
-from langgraph_api.feature_flags import USE_RUNTIME_CONTEXT_API
+from langgraph_api.feature_flags import FF_USE_CORE_API, USE_RUNTIME_CONTEXT_API
 from langgraph_api.graph import get_assistant_id, get_graph
+from langgraph_api.grpc_ops.ops import Assistants as GrpcAssistants
 from langgraph_api.js.base import BaseRemotePregel
 from langgraph_api.route import ApiRequest, ApiResponse, ApiRoute
 from langgraph_api.schema import ASSISTANT_FIELDS
-from langgraph_api.serde import ajson_loads
+from langgraph_api.serde import json_loads
 from langgraph_api.utils import (
     fetchone,
     get_pagination_headers,
@@ -40,6 +41,7 @@ from langgraph_runtime.retry import retry_db
 
 logger = structlog.stdlib.get_logger(__name__)
 
+CrudAssistants = GrpcAssistants if FF_USE_CORE_API else Assistants
 
 EXCLUDED_CONFIG_SCHEMA = (
     "__pregel_checkpointer",
@@ -55,7 +57,7 @@ def _get_configurable_jsonschema(graph: Pregel) -> dict:
 
     Important: we only return the `configurable` part of the schema.
 
-    The default get_config_schema method returns the entire schema (RunnableConfig),
+    The default get_config_schema method returns the entire schema (Config),
     which includes other root keys like "max_concurrency", which we
     do not want to expose.
 
@@ -164,7 +166,7 @@ async def create_assistant(request: ApiRequest) -> ApiResponse:
     if assistant_id := payload.get("assistant_id"):
         validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
     async with connect() as conn:
-        assistant = await Assistants.put(
+        assistant = await CrudAssistants.put(
             conn,
             assistant_id or str(uuid4()),
             config=payload.get("config") or {},
@@ -175,6 +177,7 @@ async def create_assistant(request: ApiRequest) -> ApiResponse:
             name=payload.get("name") or "Untitled",
             description=payload.get("description"),
         )
+
     return ApiResponse(await fetchone(assistant, not_found_code=409))
 
 
@@ -187,7 +190,7 @@ async def search_assistants(
     select = validate_select_columns(payload.get("select") or None, ASSISTANT_FIELDS)
     offset = int(payload.get("offset") or 0)
     async with connect() as conn:
-        assistants_iter, next_offset = await Assistants.search(
+        assistants_iter, next_offset = await CrudAssistants.search(
             conn,
             graph_id=payload.get("graph_id"),
             metadata=payload.get("metadata"),
@@ -210,7 +213,7 @@ async def count_assistants(
     """Count assistants."""
     payload = await request.json(AssistantCountRequest)
     async with connect() as conn:
-        count = await Assistants.count(
+        count = await CrudAssistants.count(
             conn,
             graph_id=payload.get("graph_id"),
             metadata=payload.get("metadata"),
@@ -226,7 +229,7 @@ async def get_assistant(
     """Get an assistant by ID."""
     validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
     async with connect() as conn:
-        assistant = await Assistants.get(conn, assistant_id)
+        assistant = await CrudAssistants.get(conn, assistant_id)
     return ApiResponse(await fetchone(assistant))
 
 
@@ -240,7 +243,7 @@ async def get_assistant_graph(
     async with connect() as conn:
         assistant_ = await Assistants.get(conn, assistant_id)
         assistant = await fetchone(assistant_)
-    config = await ajson_loads(assistant["config"])
+    config = json_loads(assistant["config"])
     configurable = config.setdefault("configurable", {})
     configurable.update(get_configurable_headers(request.headers))
 
@@ -297,7 +300,7 @@ async def get_assistant_subgraphs(
     async with connect() as conn:
         assistant_ = await Assistants.get(conn, assistant_id)
         assistant = await fetchone(assistant_)
-        config = await ajson_loads(assistant["config"])
+        config = json_loads(assistant["config"])
         configurable = config.setdefault("configurable", {})
         configurable.update(get_configurable_headers(request.headers))
         async with get_graph(
@@ -345,7 +348,7 @@ async def get_assistant_schemas(
         assistant_ = await Assistants.get(conn, assistant_id)
         # TODO Implementa  cache so we can de-dent and release this connection.
         assistant = await fetchone(assistant_)
-        config = await ajson_loads(assistant["config"])
+        config = json_loads(assistant["config"])
         configurable = config.setdefault("configurable", {})
         configurable.update(get_configurable_headers(request.headers))
         async with get_graph(
@@ -386,7 +389,7 @@ async def patch_assistant(
     validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
     payload = await request.json(AssistantPatch)
     async with connect() as conn:
-        assistant = await Assistants.patch(
+        assistant = await CrudAssistants.patch(
             conn,
             assistant_id,
             config=payload.get("config"),
@@ -405,7 +408,7 @@ async def delete_assistant(request: ApiRequest) -> Response:
     assistant_id = request.path_params["assistant_id"]
     validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
     async with connect() as conn:
-        aid = await Assistants.delete(conn, assistant_id)
+        aid = await CrudAssistants.delete(conn, assistant_id)
     await fetchone(aid)
     return Response(status_code=204)
 
@@ -417,7 +420,7 @@ async def get_assistant_versions(request: ApiRequest) -> ApiResponse:
     validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
     payload = await request.json(AssistantVersionsSearchRequest)
     async with connect() as conn:
-        assistants_iter = await Assistants.get_versions(
+        assistants_iter = await CrudAssistants.get_versions(
             conn,
             assistant_id,
             metadata=payload.get("metadata") or {},
@@ -439,7 +442,7 @@ async def set_latest_assistant_version(request: ApiRequest) -> ApiResponse:
     payload = await request.json(AssistantVersionChange)
     validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
     async with connect() as conn:
-        assistant = await Assistants.set_latest(
+        assistant = await CrudAssistants.set_latest(
             conn, assistant_id, payload.get("version")
         )
     return ApiResponse(await fetchone(assistant, not_found_code=404))
