@@ -1,5 +1,3 @@
-from typing import cast
-
 import langgraph.version
 import structlog
 from starlette.responses import JSONResponse, PlainTextResponse
@@ -48,7 +46,7 @@ async def meta_metrics(request: ApiRequest):
 
     # collect stats
     metrics = get_metrics()
-    worker_metrics = cast(dict[str, int], metrics["workers"])
+    worker_metrics = metrics["workers"]
     workers_max = worker_metrics["max"]
     workers_active = worker_metrics["active"]
     workers_available = worker_metrics["available"]
