@@ -165,6 +165,8 @@ def run_server(
     mount_prefix = None
     if http is not None and http.get("mount_prefix") is not None:
         mount_prefix = http.get("mount_prefix")
+    if os.environ.get("MOUNT_PREFIX"):
+        mount_prefix = os.environ.get("MOUNT_PREFIX")
     if os.environ.get("LANGGRAPH_MOUNT_PREFIX"):
         mount_prefix = os.environ.get("LANGGRAPH_MOUNT_PREFIX")
     if isinstance(env, str | pathlib.Path):
