@@ -179,8 +179,6 @@ REDIS_URI = env("REDIS_URI", cast=str)
 REDIS_CLUSTER = env("REDIS_CLUSTER", cast=bool, default=False)
 REDIS_MAX_CONNECTIONS = env("REDIS_MAX_CONNECTIONS", cast=int, default=2000)
 REDIS_CONNECT_TIMEOUT = env("REDIS_CONNECT_TIMEOUT", cast=float, default=10.0)
-REDIS_MAX_IDLE_TIME = env("REDIS_MAX_IDLE_TIME", cast=float, default=120.0)
-REDIS_STREAM_TIMEOUT = env("REDIS_STREAM_TIMEOUT", cast=float, default=30.0)
 REDIS_KEY_PREFIX = env("REDIS_KEY_PREFIX", cast=str, default="")
 RUN_STATS_CACHE_SECONDS = env("RUN_STATS_CACHE_SECONDS", cast=int, default=60)
 
@@ -290,8 +288,10 @@ if THREAD_TTL is None and CHECKPOINTER_CONFIG is not None:
 
 N_JOBS_PER_WORKER = env("N_JOBS_PER_WORKER", cast=int, default=10)
 BG_JOB_TIMEOUT_SECS = env("BG_JOB_TIMEOUT_SECS", cast=float, default=3600)
+
 FF_CRONS_ENABLED = env("FF_CRONS_ENABLED", cast=bool, default=True)
 FF_RICH_THREADS = env("FF_RICH_THREADS", cast=bool, default=True)
+FF_LOG_DROPPED_EVENTS = env("FF_LOG_DROPPED_EVENTS", cast=bool, default=False)
 
 # auth
 
@@ -374,6 +374,16 @@ API_VARIANT = env("LANGSMITH_LANGGRAPH_API_VARIANT", cast=str, default="")
 
 # UI
 UI_USE_BUNDLER = env("LANGGRAPH_UI_BUNDLER", cast=bool, default=False)
+
+SELF_HOSTED_METRICS_ENABLED = env(
+    "SELF_HOSTED_METRICS_ENABLED", cast=bool, default=False
+)
+SELF_HOSTED_METRICS_ENDPOINT = env(
+    "SELF_HOSTED_METRICS_ENDPOINT", cast=str, default=None
+)
+SELF_HOSTED_METRICS_EXPORT_INTERVAL_MS = env(
+    "SELF_HOSTED_METRICS_EXPORT_INTERVAL_MS", cast=int, default=60000
+)
 IS_QUEUE_ENTRYPOINT = False
 IS_EXECUTOR_ENTRYPOINT = False
 ref_sha = None
