@@ -21,12 +21,12 @@ from langgraph.pregel import Pregel
 from langgraph.store.base import BaseStore
 from starlette.exceptions import HTTPException
 
-from langgraph_api import asyncio as lg_asyncio
 from langgraph_api import config
-from langgraph_api.feature_flags import USE_RUNTIME_CONTEXT_API
+from langgraph_api.feature_flags import FF_USE_CORE_API, USE_RUNTIME_CONTEXT_API
 from langgraph_api.js.base import BaseRemotePregel, is_js_path
 from langgraph_api.schema import Config
 from langgraph_api.utils.config import run_in_executor, var_child_runnable_config
+from langgraph_api.utils.errors import GraphLoadError
 
 if TYPE_CHECKING:
     from langchain_core.embeddings import Embeddings
@@ -51,8 +51,11 @@ async def register_graph(
     description: str | None = None,
 ) -> None:
     """Register a graph."""
+    from langgraph_api.grpc_ops.ops import Assistants as AssistantsGrpc
     from langgraph_runtime.database import connect
-    from langgraph_runtime.ops import Assistants
+    from langgraph_runtime.ops import Assistants as AssistantsRuntime
+
+    Assistants = AssistantsGrpc if FF_USE_CORE_API else AssistantsRuntime
 
     await logger.ainfo(f"Registering graph with id '{graph_id}'", graph_id=graph_id)
     GRAPHS[graph_id] = graph
@@ -87,12 +90,6 @@ async def register_graph(
     await register_graph_db()
 
 
-def register_graph_sync(
-    graph_id: str, graph: GraphValue, config: dict | None = None
-) -> None:
-    lg_asyncio.run_coroutine_threadsafe(register_graph(graph_id, graph, config))
-
-
 @asynccontextmanager
 async def _generate_graph(value: Any) -> AsyncIterator[Any]:
     """Yield a graph object regardless of its type."""
@@ -392,14 +389,14 @@ async def collect_graphs_from_env(register: bool = False) -> None:
 
         if (
             config.HTTP_CONFIG
-            and config.HTTP_CONFIG.get("app")
-            and is_js_path(config.HTTP_CONFIG.get("app").split(":")[0])
+            and (js_app := config.HTTP_CONFIG.get("app"))
+            and is_js_path(js_app.split(":")[0])
         ):
             js_bg_tasks.add(
                 asyncio.create_task(
                     run_js_http_process(
                         paths_str,
-                        config.HTTP_CONFIG.get("app"),
+                        config.HTTP_CONFIG or {},
                         watch="--reload" in sys.argv[1:],
                     ),
                 )
@@ -418,7 +415,10 @@ async def collect_graphs_from_env(register: bool = False) -> None:
                 )
 
     for spec in py_specs:
-        graph = await run_in_executor(None, _graph_from_spec, spec)
+        try:
+            graph = await run_in_executor(None, _graph_from_spec, spec)
+        except Exception as exc:
+            raise GraphLoadError(spec, exc) from exc
         if register:
             await register_graph(
                 spec.id, graph, spec.config, description=spec.description
