@@ -62,7 +62,7 @@ class Checkpoint(TypedDict):
     checkpoint_map: dict[str, Any] | None
 
 
-class Assistant(TypedDict):
+class Assistant(TypedDict, total=False):
     """Assistant model."""
 
     assistant_id: UUID
@@ -176,6 +176,7 @@ class RunKwargs(TypedDict):
     subgraphs: bool
     resumable: bool
     checkpoint_during: bool
+    durability: str | None
 
 
 class Run(TypedDict):
